@@ -38,9 +38,8 @@ typedef struct {
 	gboolean proxy;
 	char *host;
 } SoupAuthPrivate;
-#define SOUP_AUTH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_AUTH, SoupAuthPrivate))
 
-G_DEFINE_ABSTRACT_TYPE (SoupAuth, soup_auth, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (SoupAuth, soup_auth, G_TYPE_OBJECT)
 
 enum {
 	PROP_0,
@@ -63,7 +62,7 @@ static void
 soup_auth_finalize (GObject *object)
 {
 	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (auth);
+	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
 
 	g_free (auth->realm);
 	g_free (priv->host);
@@ -76,7 +75,7 @@ soup_auth_set_property (GObject *object, guint prop_id,
 			const GValue *value, GParamSpec *pspec)
 {
 	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (object);
+	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
 
 	switch (prop_id) {
 	case PROP_REALM:
@@ -101,7 +100,7 @@ soup_auth_get_property (GObject *object, guint prop_id,
 			GValue *value, GParamSpec *pspec)
 {
 	SoupAuth *auth = SOUP_AUTH (object);
-	SoupAuthPrivate *priv = SOUP_AUTH_GET_PRIVATE (object);
+	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
 
 	switch (prop_id) {
 	case PROP_SCHEME_NAME:
@@ -129,13 +128,18 @@ soup_auth_get_property (GObject *object, guint prop_id,
 	}
 }
 
+static gboolean
+auth_can_authenticate (SoupAuth *auth)
+{
+	return TRUE;
+}
 
 static void
 soup_auth_class_init (SoupAuthClass *auth_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (auth_class);
 
-	g_type_class_add_private (auth_class, sizeof (SoupAuthPrivate));
+	auth_class->can_authenticate = auth_can_authenticate;
 
 	object_class->finalize     = soup_auth_finalize;
 	object_class->set_property = soup_auth_set_property;
@@ -345,9 +349,11 @@ soup_auth_authenticate (SoupAuth *auth, const char *username, const char *passwo
 gboolean
 soup_auth_is_for_proxy (SoupAuth *auth)
 {
+	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
+
 	g_return_val_if_fail (SOUP_IS_AUTH (auth), FALSE);
 
-	return SOUP_AUTH_GET_PRIVATE (auth)->proxy;
+	return priv->proxy;
 }
 
 /**
@@ -377,12 +383,13 @@ soup_auth_get_scheme_name (SoupAuth *auth)
 const char *
 soup_auth_get_host (SoupAuth *auth)
 {
+	SoupAuthPrivate *priv = soup_auth_get_instance_private (auth);
+
 	g_return_val_if_fail (SOUP_IS_AUTH (auth), NULL);
 
-	return SOUP_AUTH_GET_PRIVATE (auth)->host;
+	return priv->host;
 }
 
-
 /**
  * soup_auth_get_realm:
  * @auth: a #SoupAuth
@@ -490,6 +497,25 @@ soup_auth_is_ready (SoupAuth    *auth,
 		return SOUP_AUTH_GET_CLASS (auth)->is_authenticated (auth);
 }
 
+/**
+ * soup_auth_can_authenticate:
+ * @auth: a #SoupAuth
+ *
+ * Tests if @auth is able to authenticate by providing credentials to the
+ * soup_auth_authenticate().
+ *
+ * Return value: %TRUE if @auth is able to accept credentials.
+ *
+ * Since: 2.54
+ **/
+gboolean
+soup_auth_can_authenticate (SoupAuth *auth)
+{
+	g_return_val_if_fail (SOUP_IS_AUTH (auth), FALSE);
+
+	return SOUP_AUTH_GET_CLASS (auth)->can_authenticate (auth);
+}
+
 /**
  * soup_auth_get_protection_space:
  * @auth: a #SoupAuth
